*==============================================================================*
* TITULO DE LA SINTAXIS:                                                       *
* Sintaxis de indicadores del Plan Nacional de Desarrollo- Objetivo 1          * 
* OPERACIÓN ESTADISTICA:                                                       *
* Encuesta Nacional Multipropósito a Hogares                                   *
* UNIDAD TECNICA RESPONSABLE:                                                  *
* ENTIDAD EJECUTORA:                                                           *
*==============================================================================*
* Fecha de elaboración:        Abril 01  de 2019                               *
* Fecha ultima modificación:   Marzo 13  de 2021                               *
*==============================================================================*
* Elaborado por:                                                               *
* Instituto Nacional de Estádistica y Censos (INEC)                            *
*==============================================================================*
* Revisado y Aprobado por:                                                     *
* Direccion:                                                                   *
* Direccion de Estadisticas Sociodemográficas (DIES)                           *
* Instituto Nacional de Estadistica y Censos (INEC)                            *
*==============================================================================*
*==============================================================================*
  * INSTRUCCIONES:
*==============================================================================*
* 1. Descargue las bases de la Encuesta Multipropósito de la página del INEC. 
* 2. Coloque en una sola carpeta todas las bases. 
* 3. No cambie los nombres originales de los archivos, en caso de hacerlo,deberá 
*    remplazar los nombres en el presente archivo. 
* 4. En "cd" se debe colocar la dirección de la carpeta que contiene las bases.

	cd "......"  /*Colocar directorio*/   


*==============================================================================*
* Porcentaje de la población que realiza ejercicio o deporte en su tiempo libre 
* más de 3,5 horas a la semana
*==============================================================================*
use 202012_multibdd_educación_actfisica_tics.dta, clear 

*------------------------------------------------------------------------------*
svyset upm [iw=fexp], strata(estrato) vce(linearized) singleunit(certainty)
*------------------------------------------------------------------------------*
	  
/** Descripción de variables** 
* s6p4:: Hizo ejercicios o practicó algún deporte 
	   1= Si 
	   2= No 
* Cuánto tiempo se dedicó 
  s6p4a: Lunes a viernes - horas 
  s6p4b: Lunes a viernes - minutos 
  s6p4c: Sábado, domingo - horas 
  s6p4d: Sábado, domingo - minutos */

**Numerador:** 
recode s6p4a s6p4b s6p4c s6p4d (99=.) (999=.) 
gen tot_dep=( s6p4a + s6p4c)+ ((s6p4b+ s6p4d)/60) if s6p4==1 
gen p_tot_per_trespuntocinco=1 if (tot_dep>3.5 & s6p4==1) & s1p3>=12

**Denominador** 
replace p_tot_per_trespuntocinco=0 if (tot_dep<=3.5 & s6p4==1 & tot_dep!=.) & s1p3>=12 
replace p_tot_per_trespuntocinco=0 if s6p4==2 & s1p3>=12

gen x1=0 
replace x1=1 if p_tot_per_trespuntocinco==1 
gen y1=0 
replace y1= 1 if (p_tot_per_trespuntocinco==0 | p_tot_per_trespuntocinco==1)

* Resultados
svy: ratio x1/y1 
svy: ratio x1/y1, over(area) 
	
*==============================================================================*
* 2. Porcentaje de hogares con percepcion positiva en relacion a los servicios 
*    de salud publica
*==============================================================================*
use 202012_multibdd_salud.dta, clear
*------------------------------------------------------------------------------
svyset upm [iw=fexp5], strata(estrato5) vce(linearized) singleunit(certainty)
*------------------------------------------------------------------------------

* Caso 1 – Hogares donde alguno de sus miembros tuvo alguna enfermedad o 
* necesidad de atención de su salud y recibió atención.

gen _caso1 = 0 
replace _caso1 = 1 if s102p1==1 & s102p2<=2

* Caso 2 - Hogares donde alguno de sus miembros recibio tuvo una consulta de control

gen _caso2 = 0
replace _caso2 = 1 if ((s102p1==1 & s102p2>=3 & s102p4==1) | (s102p1==2 & s102p4==1))

* Instalaciones 
generate proc_instal = 0
replace  proc_instal = 1 if (s102p91==1 & s102p92==1 & s102p93==1 & s102p94==1 ///
 & s102p95==1)

* Servicio 
generate servicio = 0
replace  servicio = 1 if s102p10<=2

* Tiempo de espera 
generate espera = 0
replace  espera = 1 if (s102p6a==0 & s102p6b<=30)

* Numerador
generate x2 = 0
replace  x2 = 1 if ((_caso1==1 | _caso2==1) & s102p5<=5 & proc_instal==1 ///
 & servicio==1 & espera==1)

* Denominador
generate y2 = 0 
replace	 y2 = 1 if ((_caso1==1 | _caso2==1) & s102p5<=5)


* Resultados
svy:ratio x2/y2
svy:ratio x2/y2, over(area) 

*==============================================================================*
*                                     FIN
*==============================================================================*
